get_genotypemap: Get and format genotype map of an experiment

Description Usage Arguments Details Value

View source: R/genotypes.R

Description

Get and format genotype map of an experiment

Usage

1
get_genotypemap(fn, wtcode = "WT", gtypeorder = NULL)

Arguments

fn

filename of genotypemap usually stored at data/genotype_map.csv in the experiment folder

wtcode

string used to identify wild-type

gtypeorder

vector of genotype levels in custom order

Details

The standard columns for this file are plantbarcode, roi, gtype and should map each unique position in the hotel to a genotype the genotypemap is part of every experiment and maps the barcode and roi # with the genotype.

Value

tibble, with gtype as a factor.


CougPhenomics/cppcutils documentation built on Oct. 14, 2020, 5:41 a.m.