Description Usage Arguments Details
View source: R/query_waterdata.R
Fetch watering data from LT database
1 | query_waterdata(config, expername, jobname)
|
config |
configuration for database as json file |
expername |
character or vector of characters; experiment name(s) in LT database |
jobname |
character or vector of characters; job name(s) (internally stored as |
The % character is supported as a multicharacter wildcard and _ is supported as a single character wildcard for experiment and job names. names are case-sensitive!
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.