summarise_phenotypes: Summarise phenotypes

Description Usage Arguments Details Value

View source: R/summarise_phenotypes.R

Description

Summarise phenotypes

Usage

1
2
3
4
5
6
7
summarise_phenotypes(
  dF = NULL,
  phenotype = NULL,
  addgrp = NULL,
  statistic = list(med = median, sd = sd, se = se),
  na.rm = TRUE
)

Arguments

dF

dataframe of phenotypes for every individual

phenotype

column name or vector of column names of phenotypes to summarise. unquoted.

addgrp

additional columns to group by. column name or vector of column names

statistic

named list of function(s) to summarise with. name of your list entry will be used to name the new column

na.rm

logical. remove rows with NA. default is TRUE.

Details

the default is to group by gtype, idate, jobdate. For PSII data you need to additionally specify parameter

Value

dataframe with summary columns named as {statistic}_{phenotype}


CougPhenomics/cppcutils documentation built on Oct. 14, 2020, 5:41 a.m.