Description Usage Arguments Details Value
Get and format genotype map of an experiment
1 | get_genotypemap(fn, wtcode = "WT", gtypeorder = NULL)
|
fn |
filename of genotypemap usually stored at data/genotype_map.csv in the experiment folder |
wtcode |
string used to identify wild-type |
gtypeorder |
vector of genotype levels in custom order |
The standard columns for this file are plantbarcode, roi, gtype and should map each unique position in the hotel to a genotype the genotypemap is part of every experiment and maps the barcode and roi # with the genotype.
tibble, with gtype as a factor.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.