Description Usage Arguments Details Value
View source: R/summarise_phenotypes.R
Summarise phenotypes
1 2 3 4 5 6 7 |
dF |
dataframe of phenotypes for every individual |
phenotype |
column name or vector of column names of phenotypes to summarise. unquoted. |
addgrp |
additional columns to group by. column name or vector of column names |
statistic |
named list of function(s) to summarise with. name of your list entry will be used to name the new column |
na.rm |
logical. remove rows with NA. default is TRUE. |
the default is to group by gtype, idate, jobdate. For PSII data you need to additionally specify parameter
dataframe with summary columns named as {statistic}_{phenotype}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.